[Xcb-commit] 2 commits - xcb-demo

Josh Triplett josh at kemper.freedesktop.org
Mon Apr 17 15:43:45 PDT 2006


 xcb-demo/Makefile.am       |    4 ++++
 xcb-demo/tests/lissajoux.c |    4 ++--
 2 files changed, 6 insertions(+), 2 deletions(-)

New commits:
diff-tree dc95b4e98f99d69a22fa7427fe24f4d1c6439299 (from c265c493c4f11d36e0db194fbd54436b42060933)
Author: Josh Triplett <josh at freedesktop.org>
Date:   Mon Apr 17 15:43:29 2006 -0700

    Put $(XCBAUX_CFLAGS) in prog_CFLAGS for programs that use XCBAux.  Probably
    masked previously by having XCB and XCBAux in the same prefix.

diff --git a/xcb-demo/Makefile.am b/xcb-demo/Makefile.am
index 6ba5c56..321124b 100644
--- a/xcb-demo/Makefile.am
+++ b/xcb-demo/Makefile.am
@@ -10,18 +10,22 @@ LDADD = $(XCB_LIBS)
 
 bin_PROGRAMS = hypnomoire xdpyinfo xcb-test dpms rendertest xcbrandr
 
+hypnomoire_CFLAGS = $(XCBAUX_CFLAGS)
 hypnomoire_LDADD = $(LDADD) $(XCBAUX_LIBS) -lm -lpthread
 hypnomoire_SOURCES = hypnomoire.c reply_formats.c
 
 xdpyinfo_SOURCES = xdpyinfo.c
 
+xcb_test_CFLAGS = $(XCBAUX_CFLAGS)
 xcb_test_LDADD = $(LDADD) $(XCBAUX_LIBS) -lpthread
 xcb_test_SOURCES = main.c reply_formats.c
 
 dpms_SOURCES = dpms.c
 
+rendertest_CFLAGS = $(XCBAUX_CFLAGS)
 rendertest_LDADD = $(XCBAUX_LIBS)
 rendertest_SOURCES = rendertest.c
 
+xcbrandr_CFLAGS = $(XCBAUX_CFLAGS)
 xcbrandr_LDADD = $(XCBAUX_LIBS)
 xcbrandr_SOURCES = xcbrandr.c
diff-tree c265c493c4f11d36e0db194fbd54436b42060933 (from dfe7f031dc0133e356b7c9247a61edba47921850)
Author: Josh Triplett <josh at freedesktop.org>
Date:   Mon Apr 17 15:09:24 2006 -0700

    Fix typo in lissajoux: s/availaible/available/g.

diff --git a/xcb-demo/tests/lissajoux.c b/xcb-demo/tests/lissajoux.c
index 8059e57..ab58fc3 100644
--- a/xcb-demo/tests/lissajoux.c
+++ b/xcb-demo/tests/lissajoux.c
@@ -125,7 +125,7 @@ step (Data *datap)
     }
 }
 
 /* Return 0 if shm is not availaible, 1 otherwise */
 void
 shm_test (Data *datap)
 {
@@ -201,7 +201,7 @@ main (int argc, char *argv[])
     {
       printf ("Usage: lissajoux try_shm\n");
       printf ("         try_shm == 0: shm not used\n");
-      printf ("         try_shm != 0: shm is used (if availaible)\n");
+      printf ("         try_shm != 0: shm is used (if available)\n");
       exit (0);
     }
   if (argc >= 2)
@@ -125,7 +125,7 @@ step (Data *datap)
 }
 
-/* Return 0 if shm is not availaible, 1 otherwise */
+/* Return 0 if shm is not available, 1 otherwise */
 void
 shm_test (Data *datap)


More information about the xcb-commit mailing list